@@ -10,7 +10,8 @@ from typing import Optional
 
 from xrpl.models.amounts import IssuedCurrencyAmount
 from xrpl.models.required import REQUIRED
-from xrpl.models.transactions.transaction import Transaction, TransactionType
+from xrpl.models.transactions.transaction import Transaction
+from xrpl.models.transactions.types import TransactionType
 from xrpl.models.utils import require_kwargs_on_init
 
 
@@ -37,8 +38,13 @@ class TrustSet(Transaction):
     `See TrustSet <https://xrpl.org/trustset.html>`_
     """
 
-    #: This field is required.
     limit_amount: IssuedCurrencyAmount = REQUIRED  # type: ignore
+    """
+    This field is required.
+
+    :meta hide-value:
+    """
+
     quality_in: Optional[int] = None
     quality_out: Optional[int] = None
     transaction_type: TransactionType = field(
